INSERT INTO settings SET name='path_cactilog',     value='/var/log/cacti/cacti.log' ;
INSERT INTO settings SET name='path_php_binary',   value='/usr/bin/php' ;
INSERT INTO settings SET name='path_rrdtool',      value='/usr/bin/rrdtool' ;
INSERT INTO settings SET name='path_snmpbulkwalk', value='/usr/bin/snmpbulkwalk' ;
INSERT INTO settings SET name='path_snmpget',      value='/usr/bin/snmpget' ;
INSERT INTO settings SET name='path_snmpgetnext',  value='/usr/bin/snmpgetnext' ;
INSERT INTO settings SET name='path_snmptrap',     value='/usr/bin/snmptrap' ;
INSERT INTO settings SET name='path_snmpwalk',     value='/usr/bin/snmpwalk' ;
INSERT INTO settings SET name='path_spine',        value='/usr/sbin/spine' ;
INSERT INTO settings SET name='path_spine_config', value='/etc/cacti/spine.conf' ;
